==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/DecyzjaUchylajaca.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class DecyzjaUchylajaca extends GenericDPSObject {
    /**
     * DECYZJA_UCHYLAJACA.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * DECYZJA_UCHYLAJACA.EWIDENCJA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long ewidencjaId;

    /**
     * DECYZJA_UCHYLAJACA.SZABLON_WYDRUKU_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long szablonWydrukuId;

    /**
     * DECYZJA_UCHYLAJACA.NR
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String nr;

    /**
     * DECYZJA_UCHYLAJACA.DATA_WYDANIA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataWydania;

    /**
     * DECYZJA_UCHYLAJACA.DATA_UCHYLENIA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataUchylenia;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DECYZJA_UCHYLAJACA.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * DECYZJA_UCHYLAJACA.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return DECYZJA_UCHYLAJACA.EWIDENCJA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getEwidencjaId() {
        return ewidencjaId;
    }

    /**
     * DECYZJA_UCHYLAJACA.EWIDENCJA_ID
     *
     * @param ewidencjaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setEwidencjaId(Long ewidencjaId) {
        this.ewidencjaId = ewidencjaId;
    }

    /**
     * @return DECYZJA_UCHYLAJACA.SZABLON_WYDRUKU_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getSzablonWydrukuId() {
        return szablonWydrukuId;
    }

    /**
     * DECYZJA_UCHYLAJACA.SZABLON_WYDRUKU_ID
     *
     * @param szablonWydrukuId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setSzablonWydrukuId(Long szablonWydrukuId) {
        this.szablonWydrukuId = szablonWydrukuId;
    }

    /**
     * @return DECYZJA_UCHYLAJACA.NR
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getNr() {
        return nr;
    }

    /**
     * DECYZJA_UCHYLAJACA.NR
     *
     * @param nr
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNr(String nr) {
        this.nr = nr == null ? null : nr.trim();
    }

    /**
     * @return DECYZJA_UCHYLAJACA.DATA_WYDANIA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataWydania() {
        return dataWydania;
    }

    /**
     * DECYZJA_UCHYLAJACA.DATA_WYDANIA
     *
     * @param dataWydania
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataWydania(Date dataWydania) {
        this.dataWydania = dataWydania;
    }

    /**
     * @return DECYZJA_UCHYLAJACA.DATA_UCHYLENIA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataUchylenia() {
        return dataUchylenia;
    }

    /**
     * DECYZJA_UCHYLAJACA.DATA_UCHYLENIA
     *
     * @param dataUchylenia
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataUchylenia(Date dataUchylenia) {
        this.dataUchylenia = dataUchylenia;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DecyzjaUchylajaca other = (DecyzjaUchylajaca) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getEwidencjaId() == null ? other.getEwidencjaId() == null : this.getEwidencjaId().equals(other.getEwidencjaId()))
            && (this.getSzablonWydrukuId() == null ? other.getSzablonWydrukuId() == null : this.getSzablonWydrukuId().equals(other.getSzablonWydrukuId()))
            && (this.getNr() == null ? other.getNr() == null : this.getNr().equals(other.getNr()))
            && (this.getDataWydania() == null ? other.getDataWydania() == null : this.getDataWydania().equals(other.getDataWydania()))
            && (this.getDataUchylenia() == null ? other.getDataUchylenia() == null : this.getDataUchylenia().equals(other.getDataUchylenia()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getEwidencjaId() == null) ? 0 : getEwidencjaId().hashCode());
        result = prime * result + ((getSzablonWydrukuId() == null) ? 0 : getSzablonWydrukuId().hashCode());
        result = prime * result + ((getNr() == null) ? 0 : getNr().hashCode());
        result = prime * result + ((getDataWydania() == null) ? 0 : getDataWydania().hashCode());
        result = prime * result + ((getDataUchylenia() == null) ? 0 : getDataUchylenia().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", ewidencjaId=").append(ewidencjaId);
        sb.append(", szablonWydrukuId=").append(szablonWydrukuId);
        sb.append(", nr=").append(nr);
        sb.append(", dataWydania=").append(dataWydania);
        sb.append(", dataUchylenia=").append(dataUchylenia);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/DecyzjaUchylajaca.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class DecyzjaUchylajaca extends GenericDPSObject {
    /**
     * DECYZJA_UCHYLAJACA.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * DECYZJA_UCHYLAJACA.EWIDENCJA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long ewidencjaId;

    /**
     * DECYZJA_UCHYLAJACA.SZABLON_WYDRUKU_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long szablonWydrukuId;

    /**
     * DECYZJA_UCHYLAJACA.NR
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String nr;

    /**
     * DECYZJA_UCHYLAJACA.DATA_WYDANIA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataWydania;

    /**
     * DECYZJA_UCHYLAJACA.DATA_UCHYLENIA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataUchylenia;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DECYZJA_UCHYLAJACA.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * DECYZJA_UCHYLAJACA.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return DECYZJA_UCHYLAJACA.EWIDENCJA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getEwidencjaId() {
        return ewidencjaId;
    }

    /**
     * DECYZJA_UCHYLAJACA.EWIDENCJA_ID
     *
     * @param ewidencjaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setEwidencjaId(Long ewidencjaId) {
        this.ewidencjaId = ewidencjaId;
    }

    /**
     * @return DECYZJA_UCHYLAJACA.SZABLON_WYDRUKU_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getSzablonWydrukuId() {
        return szablonWydrukuId;
    }

    /**
     * DECYZJA_UCHYLAJACA.SZABLON_WYDRUKU_ID
     *
     * @param szablonWydrukuId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setSzablonWydrukuId(Long szablonWydrukuId) {
        this.szablonWydrukuId = szablonWydrukuId;
    }

    /**
     * @return DECYZJA_UCHYLAJACA.NR
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getNr() {
        return nr;
    }

    /**
     * DECYZJA_UCHYLAJACA.NR
     *
     * @param nr
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNr(String nr) {
        this.nr = nr == null ? null : nr.trim();
    }

    /**
     * @return DECYZJA_UCHYLAJACA.DATA_WYDANIA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataWydania() {
        return dataWydania;
    }

    /**
     * DECYZJA_UCHYLAJACA.DATA_WYDANIA
     *
     * @param dataWydania
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataWydania(Date dataWydania) {
        this.dataWydania = dataWydania;
    }

    /**
     * @return DECYZJA_UCHYLAJACA.DATA_UCHYLENIA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataUchylenia() {
        return dataUchylenia;
    }

    /**
     * DECYZJA_UCHYLAJACA.DATA_UCHYLENIA
     *
     * @param dataUchylenia
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataUchylenia(Date dataUchylenia) {
        this.dataUchylenia = dataUchylenia;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DecyzjaUchylajaca other = (DecyzjaUchylajaca) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getEwidencjaId() == null ? other.getEwidencjaId() == null : this.getEwidencjaId().equals(other.getEwidencjaId()))
            && (this.getSzablonWydrukuId() == null ? other.getSzablonWydrukuId() == null : this.getSzablonWydrukuId().equals(other.getSzablonWydrukuId()))
            && (this.getNr() == null ? other.getNr() == null : this.getNr().equals(other.getNr()))
            && (this.getDataWydania() == null ? other.getDataWydania() == null : this.getDataWydania().equals(other.getDataWydania()))
            && (this.getDataUchylenia() == null ? other.getDataUchylenia() == null : this.getDataUchylenia().equals(other.getDataUchylenia()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getEwidencjaId() == null) ? 0 : getEwidencjaId().hashCode());
        result = prime * result + ((getSzablonWydrukuId() == null) ? 0 : getSzablonWydrukuId().hashCode());
        result = prime * result + ((getNr() == null) ? 0 : getNr().hashCode());
        result = prime * result + ((getDataWydania() == null) ? 0 : getDataWydania().hashCode());
        result = prime * result + ((getDataUchylenia() == null) ? 0 : getDataUchylenia().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", ewidencjaId=").append(ewidencjaId);
        sb.append(", szablonWydrukuId=").append(szablonWydrukuId);
        sb.append(", nr=").append(nr);
        sb.append(", dataWydania=").append(dataWydania);
        sb.append(", dataUchylenia=").append(dataUchylenia);
        sb.append("]");
        return sb.toString();
    }
}
